@@ -9,6 +9,7 @@ import re
 import typing as T
 from textwrap import dedent
 
+from . import ParseError
 from .common import (
     Docstring,
     DocstringAttr,
@@ -172,17 +173,17 @@ class AttrSection(ParamSection):
     """
 
     def _parse_item(self, key: str, value: str) -> DocstringAttr:
-        docstringParam: DocstringParam = super()._parse_item(
+        docstring_param: DocstringParam = super()._parse_item(
             key=key,
             value=value,
         )
         return DocstringAttr(
-            args=docstringParam.args,
-            description=docstringParam.description,
-            arg_name=docstringParam.arg_name,
-            type_name=docstringParam.type_name,
-            is_optional=docstringParam.is_optional,
-            default=docstringParam.default,
+            args=docstring_param.args,
+            description=docstring_param.description,
+            arg_name=docstring_param.arg_name,
+            type_name=docstring_param.type_name,
+            is_optional=docstring_param.is_optional,
+            default=docstring_param.default,
         )
 
 
@@ -369,7 +370,7 @@ class NumpydocParser:
         self.sections[section.title] = section
         self._setup()
 
-    def parse(self, text: str) -> Docstring:
+    def parse(self, text: T.Optional[str]) -> Docstring:
         """Parse the numpy-style docstring into its components.
 
         :returns: parsed docstring
@@ -409,12 +410,21 @@ class NumpydocParser:
             # ends at the start of the next header
             start = match.end()
             end = nextmatch.start() if nextmatch is not None else None
-            ret.meta.extend(factory.parse(meta_chunk[start:end]))
+
+            substring: str = meta_chunk[start:end]
+            parsed = list(factory.parse(substring))
+
+            if substring != "" and len(parsed) == 0:
+                raise ParseError(
+                    f"Section '{title}' is not empty but nothing was parsed."
+                )
+
+            ret.meta.extend(parsed)
 
         return ret
 
 
-def parse(text: str) -> Docstring:
+def parse(text: T.Optional[str]) -> Docstring:
     """Parse the numpy-style docstring into its components.
 
     :returns: parsed docstring
@@ -437,7 +447,7 @@ def compose(
     """
 
     def process_one(
-        one: T.Union[DocstringParam, DocstringReturns, DocstringRaises]
+        one: T.Union[DocstringParam, DocstringReturns, DocstringRaises],
     ):
         if isinstance(one, DocstringParam):
             head = one.arg_name
