@@ -4,6 +4,8 @@ import inspect
 import re
 import typing as T
 
+from docstring_parser.rest_attr_parser import Attribute, parse_attributes
+
 from .common import (
     DEPRECATION_KEYWORDS,
     PARAM_KEYWORDS,
@@ -23,8 +25,6 @@ from .common import (
     RenderingStyle,
 )
 
-from docstring_parser.rest_attr_parser import Attribute, parse_attributes
-
 
 def _build_meta(args: T.List[str], desc: str) -> DocstringMeta:
     key = args[0]
@@ -120,7 +120,7 @@ def _build_meta(args: T.List[str], desc: str) -> DocstringMeta:
     return DocstringMeta(args=args, description=desc)
 
 
-def parse(text: str) -> Docstring:
+def parse(text: T.Optional[str]) -> Docstring:
     """Parse the ReST-style docstring into its components.
 
     :returns: parsed docstring
@@ -137,13 +137,13 @@ def parse(text: str) -> Docstring:
 
     # Exclude lines with attributes, because they can interfere with
     # other contents
-    text_lines: T.List[str] = text.split('\n')
+    text_lines: T.List[str] = text.split("\n")
     lines_without_attr = []
     for i, line in enumerate(text_lines):
         if i not in line_nums_with_attrs:
             lines_without_attr.append(line)
 
-    text = '\n'.join(lines_without_attr)
+    text = "\n".join(lines_without_attr)
 
     match = re.search("^:", text, flags=re.M)
     if match:
@@ -202,7 +202,7 @@ def parse(text: str) -> Docstring:
             meta.type_name = meta.type_name or ytypes.get(meta.yield_name)
 
     if not any(isinstance(m, DocstringReturns) for m in ret.meta) and rtypes:
-        for (return_name, type_name) in rtypes.items():
+        for return_name, type_name in rtypes.items():
             ret.meta.append(
                 DocstringReturns(
                     args=[],
@@ -213,19 +213,19 @@ def parse(text: str) -> Docstring:
                 )
             )
 
-
-
-    ret.meta.extend([
-        DocstringAttr(
-            args=['attr', _.name],
-            description=_.description,
-            arg_name=_.name,
-            type_name=_.type,
-            is_optional=None,
-            default=None,
-        )
-        for _ in parsed_attrs
-    ])
+    ret.meta.extend(
+        [
+            DocstringAttr(
+                args=["attr", _.name],
+                description=_.description,
+                arg_name=_.name,
+                type_name=_.type,
+                is_optional=None,
+                default=None,
+            )
+            for _ in parsed_attrs
+        ]
+    )
 
     return ret
 
