@@ -1,4 +1,5 @@
 """Tests for numpydoc-style docstring routines."""
+
 import typing as T
 
 import pytest
@@ -17,7 +18,7 @@ from docstring_parser.numpydoc import compose, parse
                 "Parameters",
                 "----------",
                 "    arg1 : str",
-                "    This is arg 1"
+                "    This is arg 1",
             ]
         ),
         "\n".join(
@@ -27,7 +28,7 @@ from docstring_parser.numpydoc import compose, parse
                 "Parameters",
                 "----------",
                 "  arg1 : str",
-                "    This is arg 1"
+                "    This is arg 1",
             ]
         ),
         "\n".join(
@@ -37,7 +38,7 @@ from docstring_parser.numpydoc import compose, parse
                 "Parameters",
                 "----------",
                 " arg1 : str",
-                "    This is arg 1"
+                "    This is arg 1",
             ]
         ),
         "\n".join(
@@ -46,7 +47,7 @@ from docstring_parser.numpydoc import compose, parse
                 "",
                 "Parameters",
                 "----------",
-                "    This is arg 1"
+                "    This is arg 1",
             ]
         ),
         "\n".join(
@@ -55,7 +56,7 @@ from docstring_parser.numpydoc import compose, parse
                 "",
                 "Returns",
                 "-------",
-                "    The return variable"
+                "    The return variable",
             ]
         ),
         "\n".join(
@@ -64,21 +65,16 @@ from docstring_parser.numpydoc import compose, parse
                 "",
                 "Yields",
                 "------",
-                "    Something yielded"
+                "    Something yielded",
             ]
         ),
         "\n".join(
-            [
-                "This is a function",
-                "",
-                "Raises",
-                "------",
-                "    Some error"
-            ]
+            ["This is a function", "", "Raises", "------", "    Some error"]
         ),
     ],
 )
 def test_detect_formatting_error(source: str) -> None:
+    """Test that formatting errors are detected and raise ParseError."""
     with pytest.raises(ParseError):
         parse(source)
 
@@ -86,6 +82,7 @@ def test_detect_formatting_error(source: str) -> None:
 @pytest.mark.parametrize(
     "source, expected",
     [
+        pytest.param(None, None, id="No __doc__"),
         ("", None),
         ("\n", None),
         ("Short description", "Short description"),
@@ -93,7 +90,9 @@ def test_detect_formatting_error(source: str) -> None:
         ("\n   Short description\n", "Short description"),
     ],
 )
-def test_short_description(source: str, expected: str) -> None:
+def test_short_description(
+    source: T.Optional[str], expected: T.Optional[str]
+) -> None:
     """Test parsing short description."""
     docstring = parse(source)
     assert docstring.short_description == expected
@@ -1198,11 +1197,11 @@ def test_compose(source: str, expected: str) -> None:
 @pytest.mark.parametrize(
     "src, expected_size",
     [
-        ('', 0),
-        ('Some text', 1),
-        ('Some text\nSome more text', 2),
-        ('Some text\n\nSome more text', 2),
-        ('Some text\n\nSome more text\n\nEven more text', 2),
+        ("", 0),
+        ("Some text", 1),
+        ("Some text\nSome more text", 2),
+        ("Some text\n\nSome more text", 2),
+        ("Some text\n\nSome more text\n\nEven more text", 2),
         (
             """
             Short description.
@@ -1238,7 +1237,7 @@ def test_compose(source: str, expected: str) -> None:
             72,
         ),
         (
-                """
+            """
                 Parameters
                 ----------
                 a: int
@@ -1265,10 +1264,10 @@ def test_compose(source: str, expected: str) -> None:
                 IOError
                     If something else goes wrong.
                 """,
-                70,
+            70,
         ),
         (
-                """
+            """
                 Short description.
     
                 This is a longer description.
@@ -1288,10 +1287,10 @@ def test_compose(source: str, expected: str) -> None:
                     TypeError: If something else goes wrong.
                     IOError: If something else goes wrong.
                 """,
-                2,  # because numpy style parser can't parse other styles
+            2,  # because numpy style parser can't parse other styles
         ),
         (
-                """
+            """
                 Args:
                     a (int): description
                     b (int): description
@@ -1307,10 +1306,10 @@ def test_compose(source: str, expected: str) -> None:
                     TypeError: If something else goes wrong.
                     IOError: If something else goes wrong.
                 """,
-                2,  # because the Arg section are parsed into long/short descriptions
+            2,  # Arg section parsed into long/short descriptions
         ),
         (
-                """
+            """
                 Short description.
 
                 This is a longer description.
@@ -1327,10 +1326,10 @@ def test_compose(source: str, expected: str) -> None:
                 :raises TypeError: If something else goes wrong.
                 :raises IOError: If something else goes wrong.
                 """,
-                2,  # because numpy style parser can't parse other styles
+            2,  # because numpy style parser can't parse other styles
         ),
         (
-                """
+            """
                 :param a: description
                 :type a: int
                 :param b: description
@@ -1343,10 +1342,11 @@ def test_compose(source: str, expected: str) -> None:
                 :raises TypeError: If something else goes wrong.
                 :raises IOError: If something else goes wrong.
                 """,
-                2,  # because the beginning is parsed into long/short descriptions
+            2,  # because the beginning is parsed into long/short descriptions
         ),
     ],
 )
 def test_docstring_size(src: str, expected_size: int) -> None:
+    """Test that docstring size is calculated correctly."""
     docstring = parse(src)
     assert docstring.size == expected_size
